@@ -828,6 +828,11 @@ int main(int argc, char *argv[]) /*{{{*/
     case 'l': line=strtol(optarg,(char**)0,10); break;
     default: fputs(_("Usage: fe [-l line] [file [file]]\n"),stderr); exit(1);
   }
+  if (optind<argc && *argv[optind]=='+')
+  {
+    line=strtol(argv[optind],(char**)0,10);
+    ++optind;
+  }
   ds_init();
   em_new();
   mc_null(&curmac);
@@ -1286,9 +1291,16 @@ int main(int argc, char *argv[]) /*{{{*/
           case '\006': /*{{{*/ /* C-x C-f -- filter region                        */
           em_filter(emdisplay[ce]); break;
           /*}}}*/
-          case '|':    /*{{{*/ /* C-x C-| -- pipe region                          */
+          case '|':    /*{{{*/ /* C-x |   -- pipe region                          */
           em_pipe(); break;
           /*}}}*/
+          case '.':    /*{{{*/ /* C-x .   -- fold region                          */
+          {
+            emdisplay[ce]->flags&=~(YANKMARK|APPENDKILL);
+            if (ds_fold()==0) showmsg(_("[You can not fold this region]"));
+            break;
+          }
+          /*}}}*/
           case '\011': /*{{{*/ /* C-x C-i -- insert file                          */
           em_insert(emdisplay[ce]); break;
           /*}}}*/
