@@ -2,7 +2,12 @@
 #define MSGLINE_H
 
 #include <sys/types.h>
+#include <stdarg.h> /* required by some curses.h implementations */
+#ifdef NEED_NCURSES
+#include <ncurses.h>
+#else
 #include <curses.h>
+#endif
 
 #define HISTORY_LEN 16
 
